@@ -70,7 +70,10 @@ static void update_progressbar (gpointer data, gpointer user_data)
 
 static gboolean timer_func (gpointer data)
 {
+	gdk_threads_enter ();
 	g_list_foreach (progressbars, update_progressbar, NULL);
+	gdk_threads_leave ();
+	
 	if (--pboffset < 0) pboffset = 9;
 	return (g_list_first(progressbars) != NULL);
 }
@@ -980,14 +983,17 @@ draw_box (DRAW_ARGS)
 			    *shadow = clearlooks_style->shade_gc[4];
 		GdkColor upper_color = *clearlooks_get_spot_color (CLEARLOOKS_RC_STYLE (style->rc_style)),
 				 lower_color;
+		GtkAdjustment *adjustment;
+		GtkOrientation orientation;
+		gint fill_size;
 		
 		gtk_widget_style_get (widget, "slider-length", &slider_length, NULL);
 		
-		GtkAdjustment *adjustment = gtk_range_get_adjustment (GTK_RANGE (widget));
+		adjustment = gtk_range_get_adjustment (GTK_RANGE (widget));
 		
-		GtkOrientation orientation = GTK_RANGE (widget)->orientation;
+		orientation = GTK_RANGE (widget)->orientation;
 		
-		gint fill_size = ((orientation ? height : width) - slider_length) * 
+		fill_size = ((orientation ? height : width) - slider_length) * 
 		                 (1 / ((adjustment->upper - adjustment->lower) / 
 		                      (adjustment->value - adjustment->lower)))
 		                 + slider_length / 2;
